@@ -23,7 +23,7 @@ try:
     def _get_memory(pid):
         process = psutil.Process(pid)
         try:
-            mem = float(process.get_memory_info()[0]) / (1024 ** 2)
+            mem = float(process.memory_info()[0]) / (1024 ** 2)
         except psutil.AccessDenied:
             mem = -1
         return mem
